@@ -9,8 +9,8 @@ fn main() {
         .run();
 }
 
-fn ui_example(egui_context: Res<EguiContext>) {
-    egui::Window::new("Hello").show(egui_context.ctx(), |ui| {
+fn ui_example(mut egui_context: ResMut<EguiContext>) {
+    egui::Window::new("Hello").show(egui_context.ctx_mut(), |ui| {
         ui.label("world");
     });
 }
